@@ -221,6 +221,13 @@ sheet_closed_cb (AdwDialog *self)
     priv->remove_callback (self, priv->user_data);
 }
 
+static void
+sheet_close_attempt_cb (AdwDialog *self)
+{
+  g_print ("a\n");
+  g_signal_emit (self, signals[SIGNAL_CLOSE_ATTEMPT], 0);
+}
+
 static void
 unset_default_widget (AdwDialog *self)
 {
@@ -443,6 +450,11 @@ update_presentation (AdwDialog *self)
 
     if (focus)
       g_object_add_weak_pointer (G_OBJECT (focus), (gpointer *) &focus);
+
+    /* FIXME: the focused widget has a strong ref and it never gets cleared. The
+     * real source of this leak is likely somewhere in GTK, but unsetting the
+     * focus "fixes" it */
+    gtk_root_set_focus (root, NULL);
   }
 
   if (priv->bottom_sheet) {
@@ -473,6 +485,8 @@ update_presentation (AdwDialog *self)
                               G_CALLBACK (sheet_closing_cb), self);
     g_signal_connect_swapped (priv->bottom_sheet, "closed",
                               G_CALLBACK (sheet_closed_cb), self);
+    g_signal_connect_swapped (priv->bottom_sheet, "close-attempt",
+                              G_CALLBACK (sheet_close_attempt_cb), self);
 
     gtk_widget_add_css_class (GTK_WIDGET (self), "bottom-sheet");
     gtk_widget_remove_css_class (GTK_WIDGET (self), "floating");
@@ -491,6 +505,7 @@ update_presentation (AdwDialog *self)
       adw_floating_sheet_set_open (priv->floating_sheet, TRUE);
 
     adw_floating_sheet_set_child (priv->floating_sheet, priv->child_breakpoint_bin);
+    adw_floating_sheet_set_can_close (priv->floating_sheet, priv->can_close);
     adw_breakpoint_bin_set_child (ADW_BREAKPOINT_BIN (priv->bin),
                                   GTK_WIDGET (priv->floating_sheet));
 
@@ -498,6 +513,8 @@ update_presentation (AdwDialog *self)
                               G_CALLBACK (sheet_closing_cb), self);
     g_signal_connect_swapped (priv->floating_sheet, "closed",
                               G_CALLBACK (sheet_closed_cb), self);
+    g_signal_connect_swapped (priv->floating_sheet, "close-attempt",
+                              G_CALLBACK (sheet_close_attempt_cb), self);
 
     gtk_widget_add_css_class (GTK_WIDGET (self), "floating");
     gtk_widget_remove_css_class (GTK_WIDGET (self), "bottom-sheet");
@@ -517,7 +534,6 @@ static void
 update_presentation_mode (AdwDialog *self)
 {
   AdwDialogPrivate *priv = adw_dialog_get_instance_private (self);
-  gboolean had_breakpoint = (priv->portrait_breakpoint != NULL);
 
   if (priv->window)
     return;
@@ -551,7 +567,7 @@ update_presentation_mode (AdwDialog *self)
     g_assert_not_reached ();
   }
 
-  if (had_breakpoint != (priv->portrait_breakpoint != NULL))
+  if (priv->bin)
     update_presentation (self);
 }
 
@@ -1470,6 +1486,9 @@ adw_dialog_set_can_close (AdwDialog *self,
   if (priv->bottom_sheet)
     adw_bottom_sheet_set_can_close (priv->bottom_sheet, can_close);
 
+  if (priv->floating_sheet)
+    adw_floating_sheet_set_can_close (priv->floating_sheet, can_close);
+
   g_object_notify_by_pspec (G_OBJECT (self), props[PROP_CAN_CLOSE]);
 }
 
@@ -1874,6 +1893,7 @@ adw_dialog_close (AdwDialog *self)
   priv = adw_dialog_get_instance_private (self);
 
   if (!priv->can_close) {
+  g_print ("b\n");
     g_signal_emit (self, signals[SIGNAL_CLOSE_ATTEMPT], 0);
     return FALSE;
   }
