@@ -79,6 +79,8 @@
  *
  * `AdwFlap` has a single CSS node with name `flap`. The node will get the style
  * classes `.folded` when it is folded, and `.unfolded` when it's not.
+ *
+ * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
  */
 
 /**
@@ -90,6 +92,8 @@
  *   space.
  *
  * Describes the possible folding behavior of a [class@Flap] widget.
+ *
+ * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
  */
 
 /**
@@ -108,7 +112,7 @@
  * [class@Flap] widget, as well as which areas can be swiped via
  * [property@Flap:swipe-to-open] and [property@Flap:swipe-to-close].
  *
- * New values may be added to this enum over time.
+ * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
  */
 
 typedef struct {
@@ -1263,11 +1267,13 @@ adw_flap_class_init (AdwFlapClass *klass)
    * The content widget.
    *
    * It's always displayed when unfolded, and partially visible when folded.
+   *
+   * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
    */
   props[PROP_CONTENT] =
     g_param_spec_object ("content", NULL, NULL,
                          GTK_TYPE_WIDGET,
-                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
+                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_DEPRECATED);
 
   /**
    * AdwFlap:flap: (attributes org.gtk.Property.get=adw_flap_get_flap org.gtk.Property.set=adw_flap_set_flap)
@@ -1275,11 +1281,13 @@ adw_flap_class_init (AdwFlapClass *klass)
    * The flap widget.
    *
    * It's only visible when [property@Flap:reveal-progress] is greater than 0.
+   *
+   * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
    */
   props[PROP_FLAP] =
     g_param_spec_object ("flap", NULL, NULL,
                          GTK_TYPE_WIDGET,
-                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
+                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_DEPRECATED);
 
   /**
    * AdwFlap:separator: (attributes org.gtk.Property.get=adw_flap_get_separator org.gtk.Property.set=adw_flap_set_separator)
@@ -1289,11 +1297,13 @@ adw_flap_class_init (AdwFlapClass *klass)
    * It's displayed between content and flap when there's no shadow to display.
    * When exactly it's visible depends on the [property@Flap:transition-type]
    * value.
+   *
+   * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
    */
   props[PROP_SEPARATOR] =
     g_param_spec_object ("separator", NULL, NULL,
                          GTK_TYPE_WIDGET,
-                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
+                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_DEPRECATED);
 
   /**
    * AdwFlap:flap-position: (attributes org.gtk.Property.get=adw_flap_get_flap_position org.gtk.Property.set=adw_flap_set_flap_position)
@@ -1302,22 +1312,26 @@ adw_flap_class_init (AdwFlapClass *klass)
    *
    * If it's set to `GTK_PACK_START`, the flap is displayed before the content,
    * if `GTK_PACK_END`, it's displayed after the content.
+   *
+   * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
    */
   props[PROP_FLAP_POSITION] =
     g_param_spec_enum ("flap-position", NULL, NULL,
                        GTK_TYPE_PACK_TYPE,
                        GTK_PACK_START,
-                       G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
+                       G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_DEPRECATED);
 
   /**
    * AdwFlap:reveal-flap: (attributes org.gtk.Property.get=adw_flap_get_reveal_flap org.gtk.Property.set=adw_flap_set_reveal_flap)
    *
    * Whether the flap widget is revealed.
+   *
+   * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
    */
   props[PROP_REVEAL_FLAP] =
     g_param_spec_boolean ("reveal-flap", NULL, NULL,
                           TRUE,
-                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
+                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_DEPRECATED);
 
   /**
    * AdwFlap:reveal-params: (attributes org.gtk.Property.get=adw_flap_get_reveal_params org.gtk.Property.set=adw_flap_set_reveal_params)
@@ -1329,11 +1343,13 @@ adw_flap_class_init (AdwFlapClass *klass)
    * ```c
    * adw_spring_params_new (1, 0.5, 500)
    * ```
+   *
+   * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
    */
   props[PROP_REVEAL_PARAMS] =
     g_param_spec_boxed ("reveal-params", NULL, NULL,
                         ADW_TYPE_SPRING_PARAMS,
-                        G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
+                        G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_DEPRECATED);
 
   /**
    * AdwFlap:reveal-progress: (attributes org.gtk.Property.get=adw_flap_get_reveal_progress)
@@ -1343,22 +1359,26 @@ adw_flap_class_init (AdwFlapClass *klass)
    * 0 means fully hidden, 1 means fully revealed.
    *
    * See [property@Flap:reveal-flap].
+   *
+   * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
    */
   props[PROP_REVEAL_PROGRESS] =
     g_param_spec_double ("reveal-progress", NULL, NULL,
                           0.0, 1.0, 1.0,
-                          G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
+                          G_PARAM_READABLE | G_PARAM_STATIC_STRINGS | G_PARAM_DEPRECATED);
 
   /**
    * AdwFlap:fold-policy: (attributes org.gtk.Property.get=adw_flap_get_fold_policy org.gtk.Property.set=adw_flap_set_fold_policy)
    *
    * The fold policy for the flap.
+   *
+   * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
    */
   props[PROP_FOLD_POLICY] =
     g_param_spec_enum ("fold-policy", NULL, NULL,
                        ADW_TYPE_FLAP_FOLD_POLICY,
                        ADW_FLAP_FOLD_POLICY_AUTO,
-                       G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
+                       G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_DEPRECATED);
 
   /**
    * AdwFlap:fold-threshold-policy: (attributes org.gtk.Property.get=adw_flap_get_fold_threshold_policy org.gtk.Property.set=adw_flap_set_fold_threshold_policy)
@@ -1371,23 +1391,27 @@ adw_flap_class_init (AdwFlapClass *klass)
    *
    * This can be useful if you have a long ellipsizing label and want to let it
    * ellipsize instead of immediately folding.
+   *
+   * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
    */
   props[PROP_FOLD_THRESHOLD_POLICY] =
     g_param_spec_enum ("fold-threshold-policy", NULL, NULL,
                        ADW_TYPE_FOLD_THRESHOLD_POLICY,
                        ADW_FOLD_THRESHOLD_POLICY_MINIMUM,
-                       G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
+                       G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_DEPRECATED);
 
   /**
    * AdwFlap:fold-duration: (attributes org.gtk.Property.get=adw_flap_get_fold_duration org.gtk.Property.set=adw_flap_set_fold_duration)
    *
    * The fold transition animation duration, in milliseconds.
+   *
+   * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
    */
   props[PROP_FOLD_DURATION] =
     g_param_spec_uint ("fold-duration", NULL, NULL,
                        0, G_MAXINT,
                        250,
-                       G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
+                       G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_DEPRECATED);
 
   /**
    * AdwFlap:folded: (attributes org.gtk.Property.get=adw_flap_get_folded)
@@ -1395,11 +1419,13 @@ adw_flap_class_init (AdwFlapClass *klass)
    * Whether the flap is currently folded.
    *
    * See [property@Flap:fold-policy].
+   *
+   * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
    */
   props[PROP_FOLDED] =
     g_param_spec_boolean ("folded", NULL, NULL,
                           FALSE,
-                          G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
+                          G_PARAM_READABLE | G_PARAM_STATIC_STRINGS | G_PARAM_DEPRECATED);
 
   /**
    * AdwFlap:locked: (attributes org.gtk.Property.get=adw_flap_get_locked org.gtk.Property.set=adw_flap_set_locked)
@@ -1409,11 +1435,13 @@ adw_flap_class_init (AdwFlapClass *klass)
    * If `FALSE`, folding when the flap is revealed automatically closes it, and
    * unfolding it when the flap is not revealed opens it. If `TRUE`,
    * [property@Flap:reveal-flap] value never changes on its own.
+   *
+   * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
    */
   props[PROP_LOCKED] =
     g_param_spec_boolean ("locked", NULL, NULL,
                           FALSE,
-                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
+                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_DEPRECATED);
 
   /**
    * AdwFlap:transition-type: (attributes org.gtk.Property.get=adw_flap_get_transition_type org.gtk.Property.set=adw_flap_set_transition_type)
@@ -1424,12 +1452,14 @@ adw_flap_class_init (AdwFlapClass *klass)
    * will be seen through it with `ADW_FLAP_TRANSITION_TYPE_OVER` transitions;
    * add the [`.background`](style-classes.html#background) style class to it if
    * this is unwanted.
+   *
+   * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
    */
   props[PROP_TRANSITION_TYPE] =
     g_param_spec_enum ("transition-type", NULL, NULL,
                        ADW_TYPE_FLAP_TRANSITION_TYPE,
                        ADW_FLAP_TRANSITION_TYPE_OVER,
-                       G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
+                       G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_DEPRECATED);
 
   /**
    * AdwFlap:modal: (attributes org.gtk.Property.get=adw_flap_get_modal org.gtk.Property.set=adw_flap_set_modal)
@@ -1439,11 +1469,13 @@ adw_flap_class_init (AdwFlapClass *klass)
    * If `TRUE`, clicking the content widget while flap is revealed, as well as
    * pressing the <kbd>Esc</kbd> key, will close the flap. If `FALSE`, clicks
    * are passed through to the content widget.
+   *
+   * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
    */
   props[PROP_MODAL] =
     g_param_spec_boolean ("modal", NULL, NULL,
                           TRUE,
-                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
+                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_DEPRECATED);
 
   /**
    * AdwFlap:swipe-to-open: (attributes org.gtk.Property.get=adw_flap_get_swipe_to_open org.gtk.Property.set=adw_flap_set_swipe_to_open)
@@ -1452,11 +1484,13 @@ adw_flap_class_init (AdwFlapClass *klass)
    *
    * The area that can be swiped depends on the [property@Flap:transition-type]
    * value.
+   *
+   * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
    */
   props[PROP_SWIPE_TO_OPEN] =
     g_param_spec_boolean ("swipe-to-open", NULL, NULL,
                           TRUE,
-                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
+                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_DEPRECATED);
 
   /**
    * AdwFlap:swipe-to-close: (attributes org.gtk.Property.get=adw_flap_get_swipe_to_close org.gtk.Property.set=adw_flap_set_swipe_to_close)
@@ -1465,11 +1499,13 @@ adw_flap_class_init (AdwFlapClass *klass)
    *
    * The area that can be swiped depends on the [property@Flap:transition-type]
    * value.
+   *
+   * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
    */
   props[PROP_SWIPE_TO_CLOSE] =
     g_param_spec_boolean ("swipe-to-close", NULL, NULL,
                           TRUE,
-                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
+                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_DEPRECATED);
 
   g_object_class_install_properties (object_class, LAST_PROP, props);
 
@@ -1758,6 +1794,8 @@ adw_flap_swipeable_init (AdwSwipeableInterface *iface)
  * Creates a new `AdwFlap`.
  *
  * Returns: the newly created `AdwFlap`
+ *
+ * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
  */
 GtkWidget *
 adw_flap_new (void)
@@ -1772,6 +1810,8 @@ adw_flap_new (void)
  * Gets the content widget for @self.
  *
  * Returns: (transfer none) (nullable): the content widget for @self
+ *
+ * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
  */
 GtkWidget *
 adw_flap_get_content (AdwFlap *self)
@@ -1789,6 +1829,8 @@ adw_flap_get_content (AdwFlap *self)
  * Sets the content widget for @self.
  *
  * It's always displayed when unfolded, and partially visible when folded.
+ *
+ * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
  */
 void
 adw_flap_set_content (AdwFlap   *self,
@@ -1797,6 +1839,9 @@ adw_flap_set_content (AdwFlap   *self,
   g_return_if_fail (ADW_IS_FLAP (self));
   g_return_if_fail (content == NULL || GTK_IS_WIDGET (content));
 
+  if (content)
+    g_return_if_fail (gtk_widget_get_parent (content) == NULL);
+
   if (self->content.widget == content)
     return;
 
@@ -1820,6 +1865,8 @@ adw_flap_set_content (AdwFlap   *self,
  * Gets the flap widget for @self.
  *
  * Returns: (transfer none) (nullable): the flap widget for @self
+ *
+ * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
  */
 GtkWidget *
 adw_flap_get_flap (AdwFlap *self)
@@ -1837,6 +1884,8 @@ adw_flap_get_flap (AdwFlap *self)
  * Sets the flap widget for @self.
  *
  * It's only visible when [property@Flap:reveal-progress] is greater than 0.
+ *
+ * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
  */
 void
 adw_flap_set_flap (AdwFlap   *self,
@@ -1845,6 +1894,9 @@ adw_flap_set_flap (AdwFlap   *self,
   g_return_if_fail (ADW_IS_FLAP (self));
   g_return_if_fail (flap == NULL || GTK_IS_WIDGET (flap));
 
+  if (flap)
+    g_return_if_fail (gtk_widget_get_parent (flap) == NULL);
+
   if (self->flap.widget == flap)
     return;
 
@@ -1869,6 +1921,8 @@ adw_flap_set_flap (AdwFlap   *self,
  * Gets the separator widget for @self.
  *
  * Returns: (transfer none) (nullable): the separator widget for @self
+ *
+ * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
  */
 GtkWidget *
 adw_flap_get_separator (AdwFlap *self)
@@ -1888,6 +1942,8 @@ adw_flap_get_separator (AdwFlap *self)
  * It's displayed between content and flap when there's no shadow to display.
  * When exactly it's visible depends on the [property@Flap:transition-type]
  * value.
+ *
+ * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
  */
 void
 adw_flap_set_separator (AdwFlap   *self,
@@ -1896,6 +1952,9 @@ adw_flap_set_separator (AdwFlap   *self,
   g_return_if_fail (ADW_IS_FLAP (self));
   g_return_if_fail (separator == NULL || GTK_IS_WIDGET (separator));
 
+  if (separator)
+    g_return_if_fail (gtk_widget_get_parent (separator) == NULL);
+
   if (self->separator.widget == separator)
     return;
 
@@ -1919,6 +1978,8 @@ adw_flap_set_separator (AdwFlap   *self,
  * Gets the flap position for @self.
  *
  * Returns: the flap position for @self
+ *
+ * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
  */
 GtkPackType
 adw_flap_get_flap_position (AdwFlap *self)
@@ -1937,6 +1998,8 @@ adw_flap_get_flap_position (AdwFlap *self)
  *
  * If it's set to `GTK_PACK_START`, the flap is displayed before the content,
  * if `GTK_PACK_END`, it's displayed after the content.
+ *
+ * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
  */
 void
 adw_flap_set_flap_position (AdwFlap     *self,
@@ -1963,6 +2026,8 @@ adw_flap_set_flap_position (AdwFlap     *self,
  * Gets whether the flap widget is revealed for @self.
  *
  * Returns: `TRUE` if the flap widget is revealed
+ *
+ * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
  */
 gboolean
 adw_flap_get_reveal_flap (AdwFlap *self)
@@ -1978,6 +2043,8 @@ adw_flap_get_reveal_flap (AdwFlap *self)
  * @reveal_flap: whether to reveal the flap widget
  *
  * Sets whether the flap widget is revealed for @self.
+ *
+ * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
  */
 void
 adw_flap_set_reveal_flap (AdwFlap  *self,
@@ -1995,6 +2062,8 @@ adw_flap_set_reveal_flap (AdwFlap  *self,
  * Gets the reveal animation spring parameters for @self.
  *
  * Returns: the reveal animation parameters
+ *
+ * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
  */
 AdwSpringParams *
 adw_flap_get_reveal_params (AdwFlap *self)
@@ -2016,6 +2085,8 @@ adw_flap_get_reveal_params (AdwFlap *self)
  * ```c
  * adw_spring_params_new (1, 0.5, 500)
  * ```
+ *
+ * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
  */
 void
 adw_flap_set_reveal_params (AdwFlap         *self,
@@ -2044,6 +2115,8 @@ adw_flap_set_reveal_params (AdwFlap         *self,
  * See [property@Flap:reveal-flap].
  *
  * Returns: the current reveal progress for @self
+ *
+ * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
  */
 double
 adw_flap_get_reveal_progress (AdwFlap *self)
@@ -2060,6 +2133,8 @@ adw_flap_get_reveal_progress (AdwFlap *self)
  * Gets the fold policy for @self.
  *
  * Returns: the fold policy for @self
+ *
+ * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
  */
 AdwFlapFoldPolicy
 adw_flap_get_fold_policy (AdwFlap *self)
@@ -2075,6 +2150,8 @@ adw_flap_get_fold_policy (AdwFlap *self)
  * @policy: the fold policy
  *
  * Sets the fold policy for @self.
+ *
+ * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
  */
 void
 adw_flap_set_fold_policy (AdwFlap           *self,
@@ -2113,6 +2190,10 @@ adw_flap_set_fold_policy (AdwFlap           *self,
  * @self: a flap
  *
  * Gets the fold threshold policy for @self.
+ *
+ * Returns: the fold threshold policy
+ *
+ * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
  */
 AdwFoldThresholdPolicy
 adw_flap_get_fold_threshold_policy (AdwFlap *self)
@@ -2135,6 +2216,8 @@ adw_flap_get_fold_threshold_policy (AdwFlap *self)
  *
  * This can be useful if you have a long ellipsizing label and want to let it
  * ellipsize instead of immediately folding.
+ *
+ * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
  */
 void
 adw_flap_set_fold_threshold_policy (AdwFlap                *self,
@@ -2160,6 +2243,8 @@ adw_flap_set_fold_threshold_policy (AdwFlap                *self,
  * Gets the fold transition animation duration for @self, in milliseconds.
  *
  * Returns: the fold transition duration
+ *
+ * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
  */
 guint
 adw_flap_get_fold_duration (AdwFlap *self)
@@ -2175,6 +2260,8 @@ adw_flap_get_fold_duration (AdwFlap *self)
  * @duration: the new duration, in milliseconds
  *
  * Sets the fold transition animation duration for @self, in milliseconds.
+ *
+ * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
  */
 void
 adw_flap_set_fold_duration (AdwFlap *self,
@@ -2199,6 +2286,8 @@ adw_flap_set_fold_duration (AdwFlap *self,
  * See [property@Flap:fold-policy].
  *
  * Returns: `TRUE` if @self is currently folded
+ *
+ * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
  */
 gboolean
 adw_flap_get_folded (AdwFlap *self)
@@ -2215,6 +2304,8 @@ adw_flap_get_folded (AdwFlap *self)
  * Gets whether @self is locked.
  *
  * Returns: `TRUE` if @self is locked
+ *
+ * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
  */
 gboolean
 adw_flap_get_locked (AdwFlap *self)
@@ -2234,6 +2325,8 @@ adw_flap_get_locked (AdwFlap *self)
  * If `FALSE`, folding when the flap is revealed automatically closes it, and
  * unfolding it when the flap is not revealed opens it. If `TRUE`,
  * [property@Flap:reveal-flap] value never changes on its own.
+ *
+ * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
  */
 void
 adw_flap_set_locked (AdwFlap  *self,
@@ -2258,6 +2351,8 @@ adw_flap_set_locked (AdwFlap  *self,
  * Gets the type of animation used for reveal and fold transitions in @self.
  *
  * Returns: the current transition type of @self
+ *
+ * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
  */
 AdwFlapTransitionType
 adw_flap_get_transition_type (AdwFlap *self)
@@ -2278,6 +2373,8 @@ adw_flap_get_transition_type (AdwFlap *self)
  * be seen through it with `ADW_FLAP_TRANSITION_TYPE_OVER` transitions; add the
  * [`.background`](style-classes.html#background) style class to it if this is
  * unwanted.
+ *
+ * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
  */
 void
 adw_flap_set_transition_type (AdwFlap               *self,
@@ -2306,6 +2403,8 @@ adw_flap_set_transition_type (AdwFlap               *self,
  * Gets whether @self is modal.
  *
  * Returns: `TRUE` if @self is modal
+ *
+ * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
  */
 gboolean
 adw_flap_get_modal (AdwFlap *self)
@@ -2325,6 +2424,8 @@ adw_flap_get_modal (AdwFlap *self)
  * If `TRUE`, clicking the content widget while flap is revealed, as well as
  * pressing the <kbd>Esc</kbd> key, will close the flap. If `FALSE`, clicks are
  * passed through to the content widget.
+ *
+ * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
  */
 void
 adw_flap_set_modal (AdwFlap  *self,
@@ -2354,6 +2455,8 @@ adw_flap_set_modal (AdwFlap  *self,
  * Gets whether @self can be opened with a swipe gesture.
  *
  * Returns: `TRUE` if @self can be opened with a swipe gesture
+ *
+ * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
  */
 gboolean
 adw_flap_get_swipe_to_open (AdwFlap *self)
@@ -2372,6 +2475,8 @@ adw_flap_get_swipe_to_open (AdwFlap *self)
  *
  * The area that can be swiped depends on the [property@Flap:transition-type]
  * value.
+ *
+ * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
  */
 void
 adw_flap_set_swipe_to_open (AdwFlap  *self,
@@ -2398,6 +2503,8 @@ adw_flap_set_swipe_to_open (AdwFlap  *self,
  * Gets whether @self can be closed with a swipe gesture.
  *
  * Returns: `TRUE` if @self can be closed with a swipe gesture
+ *
+ * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
  */
 gboolean
 adw_flap_get_swipe_to_close (AdwFlap *self)
@@ -2416,6 +2523,8 @@ adw_flap_get_swipe_to_close (AdwFlap *self)
  *
  * The area that can be swiped depends on the [property@Flap:transition-type]
  * value.
+ *
+ * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
  */
 void
 adw_flap_set_swipe_to_close (AdwFlap  *self,
