@@ -27,7 +27,7 @@
 #define HORZ_PADDING_TARGET_VALUE 120
 
 #define VERT_PADDING_MIN_HEIGHT 720
-#define VERT_PADDING_MIN_VALUE 20
+#define VERT_PADDING_MIN_VALUE 30
 #define VERT_PADDING_TARGET_HEIGHT 1440
 #define VERT_PADDING_TARGET_VALUE 120
 
@@ -44,12 +44,6 @@ struct _AdwFloatingSheet
 
   AdwAnimation *open_animation;
   double progress;
-
-  gboolean has_been_open;
-
-  GFunc closing_callback;
-  GFunc closed_callback;
-  gpointer user_data;
 };
 
 G_DEFINE_FINAL_TYPE (AdwFloatingSheet, adw_floating_sheet, GTK_TYPE_WIDGET)
@@ -65,6 +59,8 @@ enum {
 static GParamSpec *props[LAST_PROP];
 
 enum {
+  SIGNAL_CLOSING,
+  SIGNAL_CLOSED,
   SIGNAL_CLOSE_ATTEMPT,
   SIGNAL_LAST_SIGNAL,
 };
@@ -89,8 +85,7 @@ open_animation_done_cb (AdwFloatingSheet *self)
     gtk_widget_set_child_visible (self->dimming, FALSE);
     gtk_widget_set_child_visible (self->sheet_bin, FALSE);
 
-    if (self->closed_callback)
-      self->closed_callback (self, self->user_data);
+    g_signal_emit (self, signals[SIGNAL_CLOSED], 0);
   }
 }
 
@@ -115,20 +110,6 @@ sheet_close_cb (AdwFloatingSheet *self)
     gtk_widget_activate_action (parent, "sheet.close", NULL);
 }
 
-static gboolean
-maybe_close_cb (GtkWidget        *widget,
-                GVariant         *args,
-                AdwFloatingSheet *self)
-{
-  if (self->can_close && self->open) {
-    adw_floating_sheet_set_open (self, FALSE);
-    return GDK_EVENT_STOP;
-  }
-
-  g_signal_emit (self, signals[SIGNAL_CLOSE_ATTEMPT], 0);
-  return GDK_EVENT_STOP;
-}
-
 static void
 adw_floating_sheet_measure (GtkWidget      *widget,
                             GtkOrientation  orientation,
@@ -300,6 +281,32 @@ adw_floating_sheet_class_init (AdwFloatingSheetClass *klass)
 
   g_object_class_install_properties (object_class, LAST_PROP, props);
 
+  signals[SIGNAL_CLOSING] =
+    g_signal_new ("closing",
+                  G_TYPE_FROM_CLASS (klass),
+                  G_SIGNAL_RUN_LAST,
+                  0,
+                  NULL, NULL,
+                  adw_marshal_VOID__VOID,
+                  G_TYPE_NONE,
+                  0);
+  g_signal_set_va_marshaller (signals[SIGNAL_CLOSING],
+                              G_TYPE_FROM_CLASS (klass),
+                              adw_marshal_VOID__VOIDv);
+
+  signals[SIGNAL_CLOSED] =
+    g_signal_new ("closed",
+                  G_TYPE_FROM_CLASS (klass),
+                  G_SIGNAL_RUN_LAST,
+                  0,
+                  NULL, NULL,
+                  adw_marshal_VOID__VOID,
+                  G_TYPE_NONE,
+                  0);
+  g_signal_set_va_marshaller (signals[SIGNAL_CLOSED],
+                              G_TYPE_FROM_CLASS (klass),
+                              adw_marshal_VOID__VOIDv);
+
   signals[SIGNAL_CLOSE_ATTEMPT] =
     g_signal_new ("close-attempt",
                   G_TYPE_FROM_CLASS (klass),
@@ -323,8 +330,6 @@ static void
 adw_floating_sheet_init (AdwFloatingSheet *self)
 {
   AdwAnimationTarget *target;
-  GtkEventController *shortcut_controller;
-  GtkShortcut *shortcut;
 
   self->can_close = TRUE;
 
@@ -360,15 +365,6 @@ adw_floating_sheet_init (AdwFloatingSheet *self)
   adw_spring_animation_set_epsilon (ADW_SPRING_ANIMATION (self->open_animation), 0.01);
   g_signal_connect_swapped (self->open_animation, "done",
                             G_CALLBACK (open_animation_done_cb), self);
-
-  /* Esc to close */
-
-  shortcut = gtk_shortcut_new (gtk_keyval_trigger_new (GDK_KEY_Escape, 0),
-                               gtk_callback_action_new ((GtkShortcutFunc) maybe_close_cb, self, NULL));
-
-  shortcut_controller = gtk_shortcut_controller_new ();
-  gtk_shortcut_controller_add_shortcut (GTK_SHORTCUT_CONTROLLER (shortcut_controller), shortcut);
-  gtk_widget_add_controller (self->sheet_bin, shortcut_controller);
 }
 
 GtkWidget *
@@ -392,12 +388,12 @@ adw_floating_sheet_set_child (AdwFloatingSheet *self,
   g_return_if_fail (ADW_IS_FLOATING_SHEET (self));
   g_return_if_fail (child == NULL || GTK_IS_WIDGET (child));
 
-  if (self->child == child)
-    return;
-
   if (child)
     g_return_if_fail (gtk_widget_get_parent (child) == NULL);
 
+  if (self->child == child)
+    return;
+
   if (self->child)
     gtk_widget_unparent (self->child);
 
@@ -425,32 +421,21 @@ adw_floating_sheet_set_open (AdwFloatingSheet *self,
 
   open = !!open;
 
-  if (self->open == open) {
-    if (!self->has_been_open && !open) {
-      if (self->closing_callback)
-        self->closing_callback (self, self->user_data);
-
-      if (self->closed_callback)
-        self->closed_callback (self, self->user_data);
-    }
-
+  if (self->open == open)
     return;
-  }
 
   self->open = open;
 
   if (open) {
     gtk_widget_set_child_visible (self->dimming, TRUE);
     gtk_widget_set_child_visible (self->sheet_bin, TRUE);
-    self->has_been_open = true;
   }
 
   gtk_widget_set_can_target (self->dimming, open);
   gtk_widget_set_can_target (self->sheet_bin, open);
 
   if (!open) {
-    if (self->closing_callback)
-      self->closing_callback (self, self->user_data);
+    g_signal_emit (self, signals[SIGNAL_CLOSING], 0);
 
     if (self->open != open)
       return;
@@ -498,16 +483,3 @@ adw_floating_sheet_get_sheet_bin (AdwFloatingSheet *self)
 
   return self->sheet_bin;
 }
-
-void
-adw_floating_sheet_set_callbacks (AdwFloatingSheet *self,
-                                  GFunc             closing_callback,
-                                  GFunc             closed_callback,
-                                  gpointer          user_data)
-{
-  g_return_if_fail (ADW_IS_FLOATING_SHEET (self));
-
-  self->closing_callback = closing_callback;
-  self->closed_callback = closed_callback;
-  self->user_data = user_data;
-}
