@@ -63,6 +63,8 @@
  *
  * ```xml
  * <object class="AdwWindow">
+ *   <property name="width-request">360</property>
+ *   <property name="height-request">200</property>
  *   <property name="default-width">800</property>
  *   <property name="default-height">800</property>
  *   <child>
@@ -190,9 +192,6 @@ struct _AdwOverlaySplitView
   AdwLengthUnit sidebar_width_unit;
 
   int sidebar_width;
-
-  GtkWidget *last_sidebar_focus;
-  GtkWidget *last_content_focus;
 };
 
 static void adw_overlay_split_view_buildable_init (GtkBuildableIface *iface);
@@ -249,7 +248,7 @@ static void
 update_shield (AdwOverlaySplitView *self)
 {
   gtk_widget_set_child_visible (self->shield,
-                                self->collapsed && self->show_progress > 0);
+                          self->collapsed && self->show_progress > 0);
 
   gtk_widget_queue_allocate (GTK_WIDGET (self));
 }
@@ -296,11 +295,6 @@ set_show_sidebar (AdwOverlaySplitView *self,
                   gboolean             animate,
                   double               velocity)
 {
-  GtkRoot *root;
-  GtkWidget *focus;
-  gboolean focus_in_sidebar = FALSE;
-  gboolean focus_in_content = FALSE;
-
   show_sidebar = !!show_sidebar;
 
   if (self->show_sidebar == show_sidebar)
@@ -308,43 +302,9 @@ set_show_sidebar (AdwOverlaySplitView *self,
 
   self->show_sidebar = show_sidebar;
 
-  root = gtk_widget_get_root (GTK_WIDGET (self));
-  if (root)
-    focus = gtk_root_get_focus (root);
-  else
-    focus = NULL;
-
-  if (focus) {
-    if (!show_sidebar && gtk_widget_is_ancestor (focus, self->sidebar_bin)) {
-      focus_in_sidebar = TRUE;
-      g_set_weak_pointer (&self->last_sidebar_focus, focus);
-    }
-
-    if (show_sidebar && self->collapsed && gtk_widget_is_ancestor (focus, self->content_bin)) {
-      focus_in_content = TRUE;
-      g_set_weak_pointer (&self->last_content_focus, focus);
-    }
-  }
-
-  gtk_widget_set_can_focus (self->sidebar_bin, !self->collapsed || show_sidebar);
-  gtk_widget_set_can_focus (self->content_bin, !self->collapsed || !show_sidebar);
-
-  if (show_sidebar) {
+  if (show_sidebar)
     gtk_widget_set_child_visible (self->sidebar_bin, TRUE);
 
-    if (self->collapsed && focus_in_content) {
-      if (self->last_sidebar_focus)
-        gtk_widget_grab_focus (self->last_sidebar_focus);
-      else
-        gtk_widget_child_focus (self->sidebar_bin, GTK_DIR_TAB_FORWARD);
-    }
-  } else if (focus_in_sidebar) {
-    if (self->last_content_focus)
-      gtk_widget_grab_focus (self->last_content_focus);
-    else
-      gtk_widget_child_focus (self->content_bin, GTK_DIR_TAB_FORWARD);
-  }
-
   if (animate) {
     if (!self->swipe_active)
       animate_sidebar (self, show_sidebar ? 1 : 0, velocity);
@@ -437,6 +397,15 @@ released_cb (GtkGestureClick     *gesture,
   adw_overlay_split_view_set_show_sidebar (self, FALSE);
 }
 
+static inline void
+get_preferred_size (GtkWidget      *widget,
+                    GtkOrientation  orientation,
+                    int            *min,
+                    int            *nat)
+{
+  gtk_widget_measure (widget, orientation, -1, min, nat, NULL, NULL);
+}
+
 static int
 get_sidebar_width (AdwOverlaySplitView *self,
                    int                  width,
@@ -876,9 +845,6 @@ adw_overlay_split_view_dispose (GObject *object)
 {
   AdwOverlaySplitView *self = ADW_OVERLAY_SPLIT_VIEW (object);
 
-  g_clear_weak_pointer (&self->last_sidebar_focus);
-  g_clear_weak_pointer (&self->last_content_focus);
-
   g_clear_pointer (&self->sidebar_bin, gtk_widget_unparent);
   g_clear_pointer (&self->content_bin, gtk_widget_unparent);
 
@@ -908,7 +874,7 @@ adw_overlay_split_view_class_init (AdwOverlaySplitViewClass *klass)
   widget_class->compute_expand = adw_widget_compute_expand;
 
   /**
-   * AdwOverlaySplitView:content:
+   * AdwOverlaySplitView:content: (attributes org.gtk.Property.get=adw_overlay_split_view_get_content org.gtk.Property.set=adw_overlay_split_view_set_content)
    *
    * The content widget.
    *
@@ -920,7 +886,7 @@ adw_overlay_split_view_class_init (AdwOverlaySplitViewClass *klass)
                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwOverlaySplitView:sidebar:
+   * AdwOverlaySplitView:sidebar: (attributes org.gtk.Property.get=adw_overlay_split_view_get_sidebar org.gtk.Property.set=adw_overlay_split_view_set_sidebar)
    *
    * The sidebar widget.
    *
@@ -932,7 +898,7 @@ adw_overlay_split_view_class_init (AdwOverlaySplitViewClass *klass)
                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwOverlaySplitView:collapsed:
+   * AdwOverlaySplitView:collapsed: (attributes org.gtk.Property.get=adw_overlay_split_view_get_collapsed org.gtk.Property.set=adw_overlay_split_view_set_collapsed)
    *
    * Whether the split view is collapsed.
    *
@@ -947,7 +913,7 @@ adw_overlay_split_view_class_init (AdwOverlaySplitViewClass *klass)
                           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwOverlaySplitView:sidebar-position:
+   * AdwOverlaySplitView:sidebar-position: (attributes org.gtk.Property.get=adw_overlay_split_view_get_sidebar_position org.gtk.Property.set=adw_overlay_split_view_set_sidebar_position)
    *
    * The sidebar position.
    *
@@ -963,7 +929,7 @@ adw_overlay_split_view_class_init (AdwOverlaySplitViewClass *klass)
                        G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwOverlaySplitView:show-sidebar:
+   * AdwOverlaySplitView:show-sidebar: (attributes org.gtk.Property.get=adw_overlay_split_view_get_show_sidebar org.gtk.Property.set=adw_overlay_split_view_set_show_sidebar)
    *
    * Whether the sidebar widget is shown.
    *
@@ -975,7 +941,7 @@ adw_overlay_split_view_class_init (AdwOverlaySplitViewClass *klass)
                           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwOverlaySplitView:pin-sidebar:
+   * AdwOverlaySplitView:pin-sidebar: (attributes org.gtk.Property.get=adw_overlay_split_view_get_pin_sidebar org.gtk.Property.set=adw_overlay_split_view_set_pin_sidebar)
    *
    * Whether the sidebar widget is pinned.
    *
@@ -991,7 +957,7 @@ adw_overlay_split_view_class_init (AdwOverlaySplitViewClass *klass)
                           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwOverlaySplitView:enable-show-gesture:
+   * AdwOverlaySplitView:enable-show-gesture: (attributes org.gtk.Property.get=adw_overlay_split_view_get_enable_show_gesture org.gtk.Property.set=adw_overlay_split_view_set_enable_show_gesture)
    *
    * Whether the sidebar can be opened with an edge swipe gesture.
    *
@@ -1005,7 +971,7 @@ adw_overlay_split_view_class_init (AdwOverlaySplitViewClass *klass)
                           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwOverlaySplitView:enable-hide-gesture:
+   * AdwOverlaySplitView:enable-hide-gesture: (attributes org.gtk.Property.get=adw_overlay_split_view_get_enable_hide_gesture org.gtk.Property.set=adw_overlay_split_view_set_enable_hide_gesture)
    *
    * Whether the sidebar can be closed with a swipe gesture.
    *
@@ -1019,7 +985,7 @@ adw_overlay_split_view_class_init (AdwOverlaySplitViewClass *klass)
                           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwOverlaySplitView:min-sidebar-width:
+   * AdwOverlaySplitView:min-sidebar-width: (attributes org.gtk.Property.get=adw_overlay_split_view_get_min_sidebar_width org.gtk.Property.set=adw_overlay_split_view_set_min_sidebar_width)
    *
    * The minimum sidebar width.
    *
@@ -1037,7 +1003,7 @@ adw_overlay_split_view_class_init (AdwOverlaySplitViewClass *klass)
                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwOverlaySplitView:max-sidebar-width:
+   * AdwOverlaySplitView:max-sidebar-width: (attributes org.gtk.Property.get=adw_overlay_split_view_get_max_sidebar_width org.gtk.Property.set=adw_overlay_split_view_set_max_sidebar_width)
    *
    * The maximum sidebar width.
    *
@@ -1055,7 +1021,7 @@ adw_overlay_split_view_class_init (AdwOverlaySplitViewClass *klass)
                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwOverlaySplitView:sidebar-width-fraction:
+   * AdwOverlaySplitView:sidebar-width-fraction: (attributes org.gtk.Property.get=adw_overlay_split_view_get_sidebar_width_fraction org.gtk.Property.set=adw_overlay_split_view_set_sidebar_width_fraction)
    *
    * The preferred sidebar width as a fraction of the total width.
    *
@@ -1074,7 +1040,7 @@ adw_overlay_split_view_class_init (AdwOverlaySplitViewClass *klass)
                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwOverlaySplitView:sidebar-width-unit:
+   * AdwOverlaySplitView:sidebar-width-unit: (attributes org.gtk.Property.get=adw_overlay_split_view_get_sidebar_width_unit org.gtk.Property.set=adw_overlay_split_view_set_sidebar_width_unit)
    *
    * The length unit for minimum and maximum sidebar widths.
    *
@@ -1215,6 +1181,9 @@ adw_overlay_split_view_get_snap_points (AdwSwipeable *swipeable,
   gboolean can_close = self->show_progress < 1 || self->enable_hide_gesture || self->swipe_active;
   double *points;
 
+  if (!can_open && !can_close)
+    return NULL;
+
   if (can_open && can_close) {
     points = g_new0 (double, 2);
 
@@ -1310,7 +1279,7 @@ adw_overlay_split_view_new (void)
 }
 
 /**
- * adw_overlay_split_view_get_sidebar:
+ * adw_overlay_split_view_get_sidebar: (attributes org.gtk.Method.get_property=sidebar)
  * @self: an overlay split view
  *
  * Gets the sidebar widget for @self.
@@ -1328,7 +1297,7 @@ adw_overlay_split_view_get_sidebar (AdwOverlaySplitView *self)
 }
 
 /**
- * adw_overlay_split_view_set_sidebar:
+ * adw_overlay_split_view_set_sidebar: (attributes org.gtk.Method.set_property=sidebar)
  * @self: an overlay split view
  * @sidebar: (nullable): the sidebar widget
  *
@@ -1343,12 +1312,12 @@ adw_overlay_split_view_set_sidebar (AdwOverlaySplitView *self,
   g_return_if_fail (ADW_IS_OVERLAY_SPLIT_VIEW (self));
   g_return_if_fail (sidebar == NULL || GTK_IS_WIDGET (sidebar));
 
-  if (sidebar == adw_overlay_split_view_get_sidebar (self))
-    return;
-
   if (sidebar)
     g_return_if_fail (gtk_widget_get_parent (sidebar) == NULL);
 
+  if (sidebar == adw_overlay_split_view_get_sidebar (self))
+    return;
+
   adw_bin_set_child (ADW_BIN (self->sidebar_bin), sidebar);
 
   update_swipe_tracker (self);
@@ -1357,7 +1326,7 @@ adw_overlay_split_view_set_sidebar (AdwOverlaySplitView *self,
 }
 
 /**
- * adw_overlay_split_view_get_content:
+ * adw_overlay_split_view_get_content: (attributes org.gtk.Method.get_property=content)
  * @self: an overlay split view
  *
  * Gets the content widget for @self.
@@ -1375,7 +1344,7 @@ adw_overlay_split_view_get_content (AdwOverlaySplitView *self)
 }
 
 /**
- * adw_overlay_split_view_set_content:
+ * adw_overlay_split_view_set_content: (attributes org.gtk.Method.set_property=content)
  * @self: an overlay split view
  * @content: (nullable): the content widget
  *
@@ -1390,19 +1359,19 @@ adw_overlay_split_view_set_content (AdwOverlaySplitView *self,
   g_return_if_fail (ADW_IS_OVERLAY_SPLIT_VIEW (self));
   g_return_if_fail (content == NULL || GTK_IS_WIDGET (content));
 
-  if (content == adw_overlay_split_view_get_content (self))
-    return;
-
   if (content)
     g_return_if_fail (gtk_widget_get_parent (content) == NULL);
 
+  if (content == adw_overlay_split_view_get_content (self))
+    return;
+
   adw_bin_set_child (ADW_BIN (self->content_bin), content);
 
   g_object_notify_by_pspec (G_OBJECT (self), props[PROP_CONTENT]);
 }
 
 /**
- * adw_overlay_split_view_get_collapsed:
+ * adw_overlay_split_view_get_collapsed: (attributes org.gtk.Method.get_property=collapsed)
  * @self: an overlay split view
  *
  * Gets whether @self is collapsed.
@@ -1420,7 +1389,7 @@ adw_overlay_split_view_get_collapsed (AdwOverlaySplitView *self)
 }
 
 /**
- * adw_overlay_split_view_set_collapsed:
+ * adw_overlay_split_view_set_collapsed: (attributes org.gtk.Method.set_property=collapsed)
  * @self: an overlay split view
  * @collapsed: whether @self is collapsed
  *
@@ -1452,9 +1421,6 @@ adw_overlay_split_view_set_collapsed (AdwOverlaySplitView *self,
   if (!self->pin_sidebar)
     set_show_sidebar (self, !self->collapsed, FALSE, 0);
 
-  gtk_widget_set_can_focus (self->sidebar_bin, !collapsed || self->show_sidebar);
-  gtk_widget_set_can_focus (self->content_bin, !collapsed || !self->show_sidebar);
-
   update_collapsed (self);
 
   gtk_widget_queue_resize (GTK_WIDGET (self));
@@ -1479,7 +1445,7 @@ adw_overlay_split_view_set_collapsed (AdwOverlaySplitView *self,
 }
 
 /**
- * adw_overlay_split_view_get_sidebar_position:
+ * adw_overlay_split_view_get_sidebar_position: (attributes org.gtk.Method.get_property=sidebar-position)
  * @self: an overlay split view
  *
  * Gets the sidebar position for @self.
@@ -1497,7 +1463,7 @@ adw_overlay_split_view_get_sidebar_position (AdwOverlaySplitView *self)
 }
 
 /**
- * adw_overlay_split_view_set_sidebar_position:
+ * adw_overlay_split_view_set_sidebar_position: (attributes org.gtk.Method.set_property=sidebar-position)
  * @self: an overlay split view
  * @position: the new position
  *
@@ -1534,7 +1500,7 @@ adw_overlay_split_view_set_sidebar_position (AdwOverlaySplitView *self,
 }
 
 /**
- * adw_overlay_split_view_get_show_sidebar:
+ * adw_overlay_split_view_get_show_sidebar: (attributes org.gtk.Method.get_property=show-sidebar)
  * @self: an overlay split view
  *
  * Gets whether the sidebar widget is shown for @self.
@@ -1552,7 +1518,7 @@ adw_overlay_split_view_get_show_sidebar (AdwOverlaySplitView *self)
 }
 
 /**
- * adw_overlay_split_view_set_show_sidebar:
+ * adw_overlay_split_view_set_show_sidebar: (attributes org.gtk.Method.set_property=show-sidebar)
  * @self: an overlay split view
  * @show_sidebar: whether to show the sidebar widget
  *
@@ -1570,7 +1536,7 @@ adw_overlay_split_view_set_show_sidebar (AdwOverlaySplitView *self,
 }
 
 /**
- * adw_overlay_split_view_get_pin_sidebar:
+ * adw_overlay_split_view_get_pin_sidebar: (attributes org.gtk.Method.get_property=pin-sidebar)
  * @self: an overlay split view
  *
  * Gets whether the sidebar widget is pinned for @self.
@@ -1588,7 +1554,7 @@ adw_overlay_split_view_get_pin_sidebar (AdwOverlaySplitView *self)
 }
 
 /**
- * adw_overlay_split_view_set_pin_sidebar:
+ * adw_overlay_split_view_set_pin_sidebar: (attributes org.gtk.Method.set_property=pin-sidebar)
  * @self: an overlay split view
  * @pin_sidebar: whether to pin the sidebar widget
  *
@@ -1617,7 +1583,7 @@ adw_overlay_split_view_set_pin_sidebar (AdwOverlaySplitView *self,
 }
 
 /**
- * adw_overlay_split_view_get_enable_show_gesture:
+ * adw_overlay_split_view_get_enable_show_gesture: (attributes org.gtk.Method.get_property=enable-show-gesture)
  * @self: an overlay split view
  *
  * Gets whether @self can be opened with an edge swipe gesture.
@@ -1635,7 +1601,7 @@ adw_overlay_split_view_get_enable_show_gesture (AdwOverlaySplitView *self)
 }
 
 /**
- * adw_overlay_split_view_set_enable_show_gesture:
+ * adw_overlay_split_view_set_enable_show_gesture: (attributes org.gtk.Method.set_property=enable-show-gesture)
  * @self: an overlay split view
  * @enable_show_gesture: whether @self can be opened with a swipe gesture
  *
@@ -1664,7 +1630,7 @@ adw_overlay_split_view_set_enable_show_gesture (AdwOverlaySplitView *self,
 }
 
 /**
- * adw_overlay_split_view_get_enable_hide_gesture:
+ * adw_overlay_split_view_get_enable_hide_gesture: (attributes org.gtk.Method.get_property=enable-hide-gesture)
  * @self: an overlay split view
  *
  * Gets whether @self can be closed with a swipe gesture.
@@ -1682,7 +1648,7 @@ adw_overlay_split_view_get_enable_hide_gesture (AdwOverlaySplitView *self)
 }
 
 /**
- * adw_overlay_split_view_set_enable_hide_gesture:
+ * adw_overlay_split_view_set_enable_hide_gesture: (attributes org.gtk.Method.set_property=enable-hide-gesture)
  * @self: an overlay split view
  * @enable_hide_gesture: whether @self can be closed with a swipe gesture
  *
@@ -1711,7 +1677,7 @@ adw_overlay_split_view_set_enable_hide_gesture (AdwOverlaySplitView *self,
 }
 
 /**
- * adw_overlay_split_view_get_min_sidebar_width:
+ * adw_overlay_split_view_get_min_sidebar_width: (attributes org.gtk.Method.get_property=min-sidebar-width)
  * @self: an overlay split view
  *
  * Gets the minimum sidebar width for @self.
@@ -1729,7 +1695,7 @@ adw_overlay_split_view_get_min_sidebar_width (AdwOverlaySplitView *self)
 }
 
 /**
- * adw_overlay_split_view_set_min_sidebar_width:
+ * adw_overlay_split_view_set_min_sidebar_width: (attributes org.gtk.Method.set_property=min-sidebar-width)
  * @self: an overlay split view
  * @width: the minimum width
  *
@@ -1759,7 +1725,7 @@ adw_overlay_split_view_set_min_sidebar_width (AdwOverlaySplitView *self,
 }
 
 /**
- * adw_overlay_split_view_get_max_sidebar_width:
+ * adw_overlay_split_view_get_max_sidebar_width: (attributes org.gtk.Method.get_property=max-sidebar-width)
  * @self: an overlay split view
  *
  * Gets the maximum sidebar width for @self.
@@ -1777,7 +1743,7 @@ adw_overlay_split_view_get_max_sidebar_width (AdwOverlaySplitView *self)
 }
 
 /**
- * adw_overlay_split_view_set_max_sidebar_width:
+ * adw_overlay_split_view_set_max_sidebar_width: (attributes org.gtk.Method.set_property=max-sidebar-width)
  * @self: an overlay split view
  * @width: the maximum width
  *
@@ -1807,7 +1773,7 @@ adw_overlay_split_view_set_max_sidebar_width (AdwOverlaySplitView *self,
 }
 
 /**
- * adw_overlay_split_view_get_sidebar_width_fraction:
+ * adw_overlay_split_view_get_sidebar_width_fraction: (attributes org.gtk.Method.get_property=sidebar-width-fraction)
  * @self: an overlay split view
  *
  * Gets the preferred sidebar width fraction for @self.
@@ -1825,7 +1791,7 @@ adw_overlay_split_view_get_sidebar_width_fraction (AdwOverlaySplitView *self)
 }
 
 /**
- * adw_overlay_split_view_set_sidebar_width_fraction:
+ * adw_overlay_split_view_set_sidebar_width_fraction: (attributes org.gtk.Method.set_property=sidebar-width-fraction)
  * @self: an overlay split view
  * @fraction: the preferred width fraction
  *
@@ -1858,7 +1824,7 @@ adw_overlay_split_view_set_sidebar_width_fraction (AdwOverlaySplitView *self,
 }
 
 /**
- * adw_overlay_split_view_get_sidebar_width_unit:
+ * adw_overlay_split_view_get_sidebar_width_unit: (attributes org.gtk.Method.get_property=sidebar-width-unit)
  * @self: an overlay split view
  *
  * Gets the length unit for minimum and maximum sidebar widths.
@@ -1876,7 +1842,7 @@ adw_overlay_split_view_get_sidebar_width_unit (AdwOverlaySplitView *self)
 }
 
 /**
- * adw_overlay_split_view_set_sidebar_width_unit:
+ * adw_overlay_split_view_set_sidebar_width_unit: (attributes org.gtk.Method.set_property=sidebar-width-unit)
  * @self: an overlay split view
  * @unit: the length unit
  *
